/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2022  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#include <QApplication>
#include <QPainter>
#include <QStyleOptionToolButton>
#include <QPaintEvent>
#include <QRect>
#include <QPen>
#include <QBrush>
#include <QFont>
#include <QColor>

#include "button.h"

TButton::TButton(
	const QWidget						*parent)
:QToolButton(const_cast<QWidget*>(parent))
{
}

TButton::~TButton(void)
{
}

void TButton::paintEvent(
	QPaintEvent							*event)
{
	Q_UNUSED(event);
	
	QPainter							painter(this);
	QStyleOptionToolButton				style_options;
	QRect								rect;
	QPen								enabled_pen(QColor(0,0,0));
	QPen								disabled_pen(QColor(164,164,164));
	QBrush								on_brush(QColor(164,255,164));
	QBrush								off_brush(QColor(212,212,212));
	
	this->initStyleOption(&style_options);
	
	rect = style_options.rect;
	rect.adjust(1,1,-1,-1);
	
	if(this->isChecked())
	{
		painter.setBrush(on_brush);
	}
	else
	{
		painter.setBrush(off_brush);
	}
	
	if(this->isEnabled())
	{
		painter.setPen(enabled_pen);
	}
	else
	{
		painter.setPen(disabled_pen);
	}
	
	painter.drawRoundedRect(rect,30.0,30.0,Qt::RelativeSize);

	painter.setFont(style_options.font);
	
	painter.drawText(rect,Qt::AlignHCenter | Qt::AlignVCenter,style_options.text);
}