/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2022  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef VIBRATIONMETERHEADERFILE
#define VIBRATIONMETERHEADERFILE

#include <QMainWindow>
#include <vector>

#include "../core/signalprocessing.h"
#include "../core/vector2.h"

class QGridLayout;
class QAccelerometer;
class QGyroscope;
class QTiltSensor;
class QResizeEvent;
class QLabel;
class QSpacerItem;
class QProgressBar;

class TButton;
class TGraphWidget;
class TFourierTransform;

class TVibrationMeter : public QMainWindow
{
    Q_OBJECT

public:
    TVibrationMeter(const QWidget *parent = 0);
    virtual ~TVibrationMeter();

private slots:
	void Screen_Orientation_Changed(Qt::ScreenOrientation);
    void Update_Accelerometer(void);
	
	void Enable_X_Toggled(bool);
	void Enable_Y_Toggled(bool);
	void Enable_Z_Toggled(bool);
	void Enable_Zero_Toggled(bool);
	void Live_Toggled(bool);
	void Stop_Toggled(bool);
	
protected:
	virtual void resizeEvent(QResizeEvent *event);

private:

enum TDisplayMode
{
	DISPLAY_WIDE = 0,
	DISPLAY_TALL
};
	
	QGridLayout							*d_widget_layout;
	QGridLayout							*d_control_layout;
	QSpacerItem							*d_spacer_item;
	QLabel								*d_copyright_label;

    QAccelerometer						*d_accel;

	int									d_frame_size;
	int									d_frame_count;
    bool								d_initialize;
	bool								d_live_display;
	TDisplayMode						d_display_mode;
	bool								d_enable_x;
	bool								d_enable_y;
	bool								d_enable_z;
	bool								d_enable_zero;
	bool								d_enable_filter;
	bool								d_stop_updates;

	TButton								*d_enable_x_button;
	TButton								*d_enable_y_button;
	TButton								*d_enable_z_button;
	TButton								*d_live_button;
	TButton								*d_zero_button;
	TButton								*d_stop_button;
	QProgressBar						*d_live_update_progress;
	QLabel								*d_result_x_label;
	QLabel								*d_result_y_label;
	QLabel								*d_result_z_label;
	
    qint64								d_start_timestamp;
    qint64								d_draw_timestamp;
	int									d_update_display;

    TFourierTransform					d_fourier_transform;

    double								d_mean_ax;
    double								d_mean_ay;
    double								d_mean_az;
	
    TGraphWidget						*d_acceleration_graph_widget;
    TGraphWidget						*d_fourier_graph_widget;

    std::vector<TVector2>				d_acceleration_data_x;
    std::vector<TVector2>				d_acceleration_data_y;
    std::vector<TVector2>				d_acceleration_data_z;
	
	std::vector<TVector2>				d_acceleration_data_last_frame_x;
	std::vector<TVector2>				d_acceleration_data_last_frame_y;
	std::vector<TVector2>				d_acceleration_data_last_frame_z;
	
	void Update_Layout(void);
	void Update_Acceleration_View(void);
	void Update_Fourier_View(void);
	void Update_Analysis_Data(void);
	double Get_Max_Value(const std::vector<TVector2> &data) const;
	void Normalize(std::vector<TVector2> * const data,const double &max) const;
	bool Calculate_Numeric_Result(const std::vector<TVector2> &data,double * const rms, double * const peak_peak) const;
};

#endif
